@@ -9,8 +9,8 @@ import sys
 import logging
 
 from urlchecker.main.github import clone_repo, delete_repo
-from urlchecker.core.fileproc import remove_empty, save_results
-from urlchecker.core.check import run_urlchecker
+from urlchecker.core.fileproc import remove_empty
+from urlchecker.core.check import UrlChecker
 from urlchecker.logger import print_success, print_failure
 
 logger = logging.getLogger("urlchecker")
@@ -71,22 +71,24 @@ def main(args, extra):
     print("           save: %s" % args.save)
     print("        timeout: %s" % args.timeout)
 
-    # Run checks, get lookup of results and fails
-    check_results = run_urlchecker(
+    # Instantiate a new checker with provided arguments
+    checker = UrlChecker(
         path=path,
         file_types=file_types,
         include_patterns=files,
         white_listed_files=white_listed_files,
+        print_all=not args.no_print,
+    )
+    check_results = checker.run(
         white_listed_urls=white_listed_urls,
         white_listed_patterns=white_listed_patterns,
-        print_all=not args.no_print,
         retry_count=args.retry_count,
         timeout=args.timeout,
     )
 
     # save results to flie, if save indicated
     if args.save:
-        save_results(check_results, args.save)
+        checker.save_results(args.save)
 
     # delete repo when done, if requested
     if args.cleanup:
